@@ -27,10 +27,12 @@ from pandemy.exceptions import (
    DataTypeConversionError,
    DeleteFromTableError,
    ExecuteStatementError,
+   InvalidColumnNameError,
    InvalidTableNameError,
    LoadTableError,
    SaveDataFrameError,
    SetIndexError,
+   SQLStatementNotSupportedError,
    TableExistsError
 )
 
@@ -49,7 +51,7 @@ from pandemy.databasemanager import (
 # Attributes
 # ===============================================================
 
-__versiontuple__: Tuple[Union[int, str], ...] = (1, 1, 0)
+__versiontuple__: Tuple[Union[int, str], ...] = (1, 2, 0)
 r"""The version of Pandemy in a comparable form.
 
 Adheres to `Semantic Versioning <https://semver.org/spec/v2.0.0.html>`_
@@ -65,10 +67,10 @@ Examples
    True
 """
 
-__version__ = '1.1.0'
+__version__ = '1.2.0'
 r"""The Pandemy version string."""
 
-__releasedate__: date = date(2022, 4, 9)
+__releasedate__: date = date(2023, 2, 6)
 r"""The release date of the version specified in :data:`__versiontuple__`."""
 
 # ===============================================================
@@ -86,10 +88,12 @@ __all__ = [
    'DataTypeConversionError',
    'DeleteFromTableError',
    'ExecuteStatementError',
+   'InvalidColumnNameError',
    'InvalidTableNameError',
    'LoadTableError',
    'SaveDataFrameError',
    'SetIndexError',
+   'SQLStatementNotSupportedError',
    'TableExistsError',
 
    # sqlcontainer
