@@ -74,6 +74,13 @@ class ExecuteStatementError(DatabaseManagerError):
     """
 
 
+class InvalidColumnNameError(DatabaseManagerError):
+    r"""Errors when supplying an invalid column name to a database operation.
+
+    .. versionadded:: 1.2.0
+    """
+
+
 class InvalidTableNameError(DatabaseManagerError):
     r"""Errors when supplying an invalid table name to a database operation."""
 
@@ -92,5 +99,12 @@ class SetIndexError(DatabaseManagerError):
     """
 
 
+class SQLStatementNotSupportedError(DatabaseManagerError):
+    r"""Errors when executing a method that triggers a SQL statement not supported by the database dialect.
+
+    .. versionadded:: 1.2.0
+    """
+
+
 class TableExistsError(DatabaseManagerError):
     r"""Errors when saving a :class:`pandas.DataFrame` to a table and the table already exists."""
